@@ -808,6 +808,15 @@ class IMAPSequenceSetTest < Net::IMAP::TestCase
     assert_equal SequenceSet["678"],     SequenceSet["345,678"].max(1)
     assert_equal SequenceSet["345,678"], SequenceSet["345,678"].max(222)
     assert_equal SequenceSet.empty,      SequenceSet.new.max(5)
+    # with different cardinality (150) vs size (200)
+    set = SequenceSet["101:200,51:150"]
+    assert_equal SequenceSet["52:200"], set.max(149)
+    assert_equal SequenceSet["51:200"], set.max(150)
+    assert_equal SequenceSet["51:200"], set.max(200)
+    # with different cardinality (2**32) vs count (2**32 - 1)
+    set = SequenceSet[1..]
+    assert_equal SequenceSet["2:*"], set.max(2**32 - 1)
+    assert_equal SequenceSet["1:*"], set.max(2**32)
   end
 
   test "#minmax" do
@@ -834,13 +843,21 @@ class IMAPSequenceSetTest < Net::IMAP::TestCase
 
   test "#delete?" do
     set = SequenceSet.new [5..10, 20]
+    # deleting a number
     assert_nil   set.delete?(11)
     assert_equal SequenceSet[5..10, 20], set
     assert_equal 6, set.delete?(6)
     assert_equal SequenceSet[5, 7..10, 20], set
+    # deleting a range
     assert_equal SequenceSet[9..10, 20],    set.delete?(9..)
     assert_equal SequenceSet[5, 7..8],      set
     assert_nil   set.delete?(11..)
+    set = SequenceSet.new [5..11, 20, 30..40]
+    assert_equal SequenceSet[9..11, 20, 30..33], set.delete?(9..33)
+    assert_equal SequenceSet[5..8, 34..40], set
+    set = SequenceSet.new [5..11, 20, 30..40]
+    # deleting a single-member range
+    assert_equal SequenceSet[9], set.delete?(9..9)
   end
 
   test "#slice!" do
